| Package name                                                  | Package hash                                                  | Description                                                                                                                |
| ------------------------------------------------------------- | ------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------- |
| protocol/valory/abci/0.1.0                                    | `bafybeig3dj5jhsowlvg3t73kgobf6xn4nka7rkttakdb2gwsg5bp7rt7q4` | A protocol for ABCI requests and responses.                                                                                |
| connection/valory/abci/0.1.0                                  | `bafybeihkimb5kmtrhapmvix2od3u3qocqz4zfcjvaphj4t4sardtjgsfqy` | connection to wrap communication with an ABCI server.                                                                      |
| connection/valory/ipfs/0.1.0                                  | `bafybeifkzgdzuoxqovcjswsnzsehjh7bjwbska26ufmcrk7hbufk4c4dae` | A connection responsible for uploading and downloading files from IPFS.                                                    |
| contract/valory/gnosis_safe_proxy_factory/0.1.0               | `bafybeifydgooxpzav7b7blpxj4p5arytmjqphdcyl46egs3htnj2fszora` | Gnosis Safe proxy factory (GnosisSafeProxyFactory) contract                                                                |
| contract/valory/component_registry/0.1.0                      | `bafybeifeujuzp56zzdhyvxitnaakqetcqhbqr2x6jxnhj7ahzm7pb2y7uy` | Component registry contract                                                                                                |
| contract/valory/agent_registry/0.1.0                          | `bafybeifdrul5qvk5hj4ggy63ff3smt6wc4c67srnqxxfpbz3jsgbpuavgy` | Agent registry contract                                                                                                    |
| contract/valory/registries_manager/0.1.0                      | `bafybeiax2b4upu7uiea4otvc5jv3rnmnnb6g2bmb2jkrhqtuyjyylskt6i` | Registries Manager contract                                                                                                |
| contract/valory/service_manager/0.1.0                         | `bafybeihvogcziooqau7n22tejzan2baghjaodkb2u74i3aao7ffomk4aem` | Service Manager contract                                                                                                   |
| skill/valory/test_ipfs_abci/0.1.0                             | `bafybeifp7dz2elwaa3xdplbspmqants2h6xi4qfsieurzqrrw6esjtydiu` | IPFS e2e testing application.                                                                                              |
| agent/valory/test_ipfs/0.1.0                                  | `bafybeid4ruskvxhyqngr7iiphlhcnkitowu555p4gbh4josde7hfyrsjdm` | Agent for testing the ABCI connection.                                                                                     |
| contract/valory/service_registry/0.1.0                        | `bafybeics2gdksww76emw5b7hyph75t7l72dpnls6qua5yfzwpeeezolnhq` | Service Registry contract                                                                                                  |
| protocol/valory/tendermint/0.1.0                              | `bafybeicusvezoqlmyt6iqomcbwaz3xkhk2qf3d56q5zprmj3xdxfy64k54` | A protocol for communication between two AEAs to share tendermint configuration details.                                   |
| protocol/valory/ipfs/0.1.0                                    | `bafybeic72ncgqbzoz2guj4p4yjqulid7mv6yroeh65hxznloamoveeg7hq` | A protocol specification for IPFS requests and responses.                                                                  |
| skill/valory/abstract_abci/0.1.0                              | `bafybeigqr6dzr23r6oxbnpxqyae7g5ndjy75oatjk6liyrvmpb2jxehirq` | The abci skill provides a template of an ABCI application.                                                                 |
| contract/valory/gnosis_safe/0.1.0                             | `bafybeig2dobzlupi4twn3lv2avfajslgjukkmkdd4qzf37cbfv7ojupv54` | Gnosis Safe (GnosisSafeL2) contract                                                                                        |
| skill/valory/abstract_round_abci/0.1.0                        | `bafybeich3i7gwcyuqg6t3zrvsapoxrkvadpjcs4klaf7ngsmzqdshhpadm` | abstract round-based ABCI application                                                                                      |
| contract/valory/multisend/0.1.0                               | `bafybeigjywkl7hydjsrkogob3xebj2ifhqwmfhhxoeyrndzhhxi5u6amey` | MultiSend contract                                                                                                         |
| skill/valory/transaction_settlement_abci/0.1.0                | `bafybeiez6nwt2ry7aym3b2rt772arlkrds5ldcwhj4i5ixkwqpsvfmwcay` | ABCI application for transaction settlement.                                                                               |
| skill/valory/registration_abci/0.1.0                          | `bafybeicnrovt3uixevtq6iq74qmeowr3mol3vbbbri7aik3ph5ykyrof7m` | ABCI application for common apps.                                                                                          |
| skill/valory/reset_pause_abci/0.1.0                           | `bafybeiguazfpzemsyodwnw5hcvye5ayvdkqoyiv4scwoxty2xcik6ydg64` | ABCI application for resetting and pausing app executions.                                                                 |
| skill/valory/termination_abci/0.1.0                           | `bafybeifqnkcg5okyniuv4yf6hml7acsn63hlwobrdnkiu4j5mmsyxkg5ca` | Termination skill.                                                                                                         |
| skill/valory/counter/0.1.0                                    | `bafybeia5ib7kllbdwlhxyrmeiooefibgrmwrnkb3wtlb47qktemou7uomi` | The ABCI Counter application example.                                                                                      |
| skill/valory/counter_client/0.1.0                             | `bafybeiaqdfulxamdshw7fykfkqvkpvjb5bnmhv7ffrjiwdi4ktiulklx6q` | A client for the ABCI counter application.                                                                                 |
| skill/valory/hello_world_abci/0.1.0                           | `bafybeidt6bgo7mzc7mb7flwwd6wacr24paxtvtvgodbzxaaewtcmkbt6ly` | Hello World ABCI application.                                                                                              |
| skill/valory/register_reset_abci/0.1.0                        | `bafybeib75acbsovba6yflqvtp4ak6y5yfz3y6n4t4wjyextlrjez5ansx4` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/register_termination_abci/0.1.0                  | `bafybeieiffkxmu5g2jmbvdpidcyspjjrdymtmrrqpkybkh4ffxjoqlfo3y` | ABCI application for dummy skill that registers and resets                                                                 |
| skill/valory/test_abci/0.1.0                                  | `bafybeibrn7bge3gxcibzeteei3vyjyvobpwezutaea23ry7dfaelq4vvbe` | ABCI application for testing the ABCI connection.                                                                          |
| agent/valory/abstract_abci/0.1.0                              | `bafybeibw7a4coba3cwyacyzcltem4sb576gd5nx7pjbpygi7ffbcv2nayq` | The abstract ABCI AEA - for testing purposes only.                                                                         |
| agent/valory/counter/0.1.0                                    | `bafybeigwemru3zuab2vcpnc6unjvytjy2cpunjd6aq2kynry6majxynljy` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/counter_client/0.1.0                             | `bafybeiesdrai2lvgnwf5og4xh5n2f23giboxoivkuqj33x56xz6hgczav4` | The ABCI Counter example as an AEA                                                                                         |
| agent/valory/hello_world/0.1.0                                | `bafybeih7w43g4awi6gjykchtn676aad5gjmixu4aovnuyvfsbxarcqcj4u` | Hello World ABCI example.                                                                                                  |
| agent/valory/register_reset/0.1.0                             | `bafybeic5vaxqzdy7a2opbcncqxz3fgoka5kfp273gq6rbgzlyivatocouq` | Register reset to replicate Tendermint issue.                                                                              |
| agent/valory/register_termination/0.1.0                       | `bafybeiea5f5za25kuxx6xghonkv4yb2qxjh55qn42yxwfujwlxkvd5paou` | Register terminate to test the termination feature.                                                                        |
| agent/valory/registration_start_up/0.1.0                      | `bafybeiepsqs3ypjxawwpemvicsxsdm4uoldcxncixjounavo63uiorrqd4` | Registration start-up ABCI example.                                                                                        |
| agent/valory/test_abci/0.1.0                                  | `bafybeienh26iwughk54mb7sk3qfpw6dlbgmiqlwt3xqzsef4kn56a5dcee` | Agent for testing the ABCI connection.                                                                                     |
| service/valory/counter/0.1.0                                  | `bafybeie5t6g4rcdj6qd2k7gmbjpffa63fkuv7p3n23y7yo245nmw47hb5i` | A set of agents incrementing a counter                                                                                     |
| service/valory/hello_world/0.1.0                              | `bafybeif4du72b6ixhkdqcfkfpq4ctijycii2scahhrn3s75hqoxjuk7bzu` | A simple demonstration of a simple ABCI application                                                                        |
| service/valory/register_reset/0.1.0                           | `bafybeiaprb5eoq5zbyptyk4p2sewjwbuzwq7eamo36ff2brgyy5jmin7dm` | Test and debug tendermint reset mechanism.                                                                                 |
| skill/valory/register_reset_recovery_abci/0.1.0               | `bafybeihi5xbzan7ebmfnf46vzlhfhauwnfe47yfx5gynq6bti3hlglm3vq` | ABCI application for dummy skill that registers and resets                                                                 |
| agent/valory/register_reset_recovery/0.1.0                    | `bafybeigsrazmgnj7qqpkhicawv45wn4rb5xibespnbdempctqey2judc6e` | Agent to showcase hard reset as a recovery mechanism.                                                                      |
| contract/valory/multicall2/0.1.0                              | `bafybeial5db7mcobpr4ntjxjgdqysrxlkbj3hrruuikvfyi66lmetzhoai` | The MakerDAO multicall2 contract.                                                                                          |
| protocol/open_aea/signing/1.0.0                               | `bafybeibqlfmikg5hk4phzak6gqzhpkt6akckx7xppbp53mvwt6r73h7tk4` | A protocol for communication between skills and decision maker.                                                            |
| protocol/valory/acn/1.1.0                                     | `bafybeignmc5uh3vgpuckljcj2tgg7hdqyytkm6m5b6v6mxtazdcvubibva` | The protocol used for envelope delivery on the ACN.                                                                        |
| protocol/valory/http/1.0.0                                    | `bafybeifyoio7nlh5zzyn5yz7krkou56l22to3cwg7gw5v5o3vxwklibhty` | A protocol for HTTP requests and responses.                                                                                |
| protocol/valory/ledger_api/1.0.0                              | `bafybeibo4bdtcrxi2suyzldwoetjar6pqfzm6vt5xal22ravkkcvdmtksi` | A protocol for ledger APIs requests and responses.                                                                         |
| protocol/valory/contract_api/1.0.0                            | `bafybeidv6wxpjyb2sdyibnmmum45et4zcla6tl63bnol6ztyoqvpl4spmy` | A protocol for contract APIs requests and responses.                                                                       |
| connection/valory/http_client/0.23.0                          | `bafybeidykl4elwbcjkqn32wt5h4h7tlpeqovrcq3c5bcplt6nhpznhgczi` | The HTTP_client connection that wraps a web-based client connecting to a RESTful API specification.                        |
| connection/valory/ledger/0.19.0                               | `bafybeicgfupeudtmvehbwziqfxiz6ztsxr5rxzvalzvsdsspzz73o5fzfi` | A connection to interact with any ledger API and contract API.                                                             |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeidwcobzb7ut3efegoedad7jfckvt2n6prcmd4g7xnkm6hp6aafrva` | The libp2p client connection implements a tcp connection to a running libp2p node as a traffic delegate to send/receive envelopes to/from agents in the DHT. |
